use strict;
package POE::Component::Server::HTTP::Response;

use vars qw(@ISA);
use HTTP::Response;
@ISA = qw(HTTP::Response);

use POE;

sub streaming {
    my $self = shift;
    if (@_) {
        if ($_[0]) {
            $self->{streaming} = 1;
        }
        else {
            $self->{streaming} = 0;
        }
    }
    return $self->{streaming};
}

sub is_error {
    my $self = shift;
    if (@_) {
        if ($_[0]) {
            $self->{is_error} = 1;
        }
        else {
            $self->{is_error} = 0;
        }
    }
    return $self->{is_error};
}

sub send {
    my $self = shift;
    $self->{connection}->{wheel}->put(@_);
}

sub continue {
    my $self = shift;
    $poe_kernel->post($self->{connection}->{session},
                      'execute' => $self->{connection}->{my_id});
}

sub close {
    my $self = shift;
    $self->{streaming} = 0;
    shift @{$self->{connection}->{handlers}->{Queue}};
}

sub connection {
    my $self = shift;
    return $self->{connection};
}

1;

__END__

=head1 NAME

POE::Component::Server::HTTP::Response - Response object for a POE HTTP Daemon

=head1 SYNOPSIS

    sub handler1 {
        my ($request, $response) = @_;
        $response->code( 200 );
        $response->content_type( 'text/plain' );

        $response->streaming( 1 );
        $response->send( $data );
        $response->close;
        my $connection = $response->connection;

        unless( $response->is_error) {
            my $uniqueID = $connect->ID;
            $connection->on_close( 'conn_close', $uniqueID );
        }
        $response->continue;
    }

=head1 DESCRIPTION

POE::Component::Server::HTTP::Response encapsulates information related to
a single HTTP response.  Because of HTTP connection persistance, a single
connection may be use for more then one request and response.

POE::Component::Server::HTTP::Response is a sub-class of L<HTTP::Response>.
Use those methods to build a response to a request.

=head1 METHODS

=head2 continue

A HTTP event handler may return RC_WAIT.  It may then use furthur POE events
to handle a request.  When done, the application then calls C<continue> to 
finish the request.

    sub handler1 {
        my( $request, $response ) = @_;
        $poe_kernel->post( MySession => 'do_work', $request, $response );
        return RC_WAIT;
    }

    sub do_work {
        my( $request, $response ) = @_[ARG0, ARG1 ];
        $response->code( 200 );
        # ... build the rest of the response
        $response->continue;
    }

=head2 connection

Returns the connection object.  See
L<POE::Component::Server::HTTP::Connection>.

=head2 streaming

Turns on streaming response.

=head2 send

Sends streaming data to the client.

=head2 close

Ends streaming response.

=head2 is_error

Get or set the error state on a response.

=head1 See Also

Please also take a look at L<HTTP::Response>, L<HTTP::Request>,
L<POE::Component::Server::HTTP>, L<URI>, L<POE> and L<POE::Filter::HTTPD>.

=head1 TODO

=head1 AUTHOR

Arthur Bergman, arthur@contiller.se

Additional hacking by Philip Gwyn, poe-at-pied.nu

Released under the same terms as POE.

=cut
